@@ -35,7 +35,7 @@
 
 RSDialog::RSDialog(QWidget* parent) : QDialog(parent)
 {
-    setWindowTitle(i18n("Risks/Security Phrases"));
+    setWindowTitle(i18nc("@title:window", "Risks/Security Phrases"));
     QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Help|QDialogButtonBox::Close);
     QWidget *mainWidget = new QWidget(this);
     QVBoxLayout *mainLayout = new QVBoxLayout;
